function coal_rot, data, angle0, index_in=index, index_out = index_out, $
	corn2sc=corn2sc, new_corn=new_corn, $
	missing=missing, qdebug=qdebug, qstop=qstop, $
	cen=cen
;
;+
;NAME:
;	coal_rot
;PURPOSE:
;	To perform the rotation step for the co-alignment of two images.
;SAMPLE CALLING SEQUENCE:
;	data_out = coal_rot(data, angle, index_in=index, index_out=index_out)
;	data_out = coal_rot(data, angle, corn2sc=corn2sc)
;INPUT:
;	data	- The data array or cube
;	angle	- the angle to rotate clockwise.  It can be an array if 
;		  "data" is an data cube.
;KEYWORD INPUT:
;	index_in- The SXT index structure.  If the index is not passed, then
;		  "corn2sc" needs to be passed.
;	corn2sc	- The lower left corner of the image in pixels relative to
;		  sun center.
;	missing	- The data value to insert into the output array for pixels
;		  where there is no data
;
;	qdebug	- If set, print some diagnostic messages
;	qstop	- If set, stop before exiting
;KEYWORD OUTPUT:
;	index_out- The new updated SXT index structure.
;	new_corn-  The lower left corner of the image in pixels relative to
;		   sun center
;	cen	-  The coordinates of the sun center.
;METHOD:
;	The routine uses ROT, but before it does so, it imbeds the input
;	image into a larger array so that the corners are not lost
;HISTORY:
;	Written by M.Morrison 10-Aug-93
;-
;
his_index, /enable
;
if (n_elements(mag) eq 0) then mag = 1.0
;
nx0 = n_elements(data(*,0,0))
ny0 = n_elements(data(0,*,0))
n   = n_elements(data(0,0,*))
;
if (keyword_set(index)) then begin
    cen = sxt_cen(index)
    corn2sc = gt_corner(index) - cen(0:1, *)	;corner pixel address relative to sun center (ie: sun center would be at (0,0))
    corn2sc(0,*) = corn2sc(0,*) / 2.^gt_res(index)	;convert corner units to summed pixel coordinates
    corn2sc(1,*) = corn2sc(1,*) / 2.^gt_res(index)	;convert corner units to summed pixel coordinates
    index_out = index
end else begin
    cen = intarr(2,n)
end
;
angle = angle0
if (n_elements(angle) ne n) then angle = float(n) + angle(0)
angler = angle*!pi/180	;angle in radians
;
nxout = intarr(n)
nyout = intarr(n)
x_embed = intarr(n)
y_embed = intarr(n)
new_corn = fltarr(2,n)
;
for i=0,n-1 do begin
    x0 = corn2sc(0,i)
    y0 = corn2sc(1,i)
    xarr0 = [x0, x0+(nx0-1),       x0, x0+(nx0-1), x0+(nx0-1)/2.]	;coordinates of the four corners of the original image 
    yarr0 = [y0,       y0, y0+(ny0-1), y0+(ny0-1), y0+(ny0-1)/2.]	;plus the coordinate of the center
    xarr1 =  cos(angler(i))*xarr0 + sin(angler(i))*yarr0
    yarr1 = -sin(angler(i))*xarr0 + cos(angler(i))*yarr0
    xx0 = min(xarr1)	;corner of new larger image, relative to sun center
    xx1 = max(xarr1)
    yy0 = min(yarr1)
    yy1 = max(yarr1)

    nxout(i) = fix(xx1-xx0+0.5)
    nyout(i) = fix(yy1-yy0+0.5)
    dx0 = xarr0(4) - xarr0(0)	;distance from the corner that the center of the image 
    dy0 = yarr0(4) - yarr0(0)
    dx1 = xarr1(4) - xx0
    dy1 = yarr1(4) - yy0
    x_embed(i) = fix( dx1-dx0+0.5 )	;how far does the center of the image move - could be up to sqrt(2)*nx/2
    y_embed(i) = fix( dy1-dy0+0.5 )
    new_corn(0,i) = xx0
    new_corn(1,i) = yy0

    if (keyword_set(qdebug)) then begin
	print, '---------------------------------------- Image: ', i
	print, 'Original corners/cen:   X', xarr0
	print, '                        Y', yarr0
	print, 'Translated corners/cen: X', xarr1
	print, '                        Y', yarr1
	print, 'New Corner: ', xx0, yy0, '  Embed values: ', x_embed(i), y_embed(i)
    end
end
;
nx = max(nxout)
ny = max(nyout)
;
if (keyword_set(qdebug)) then print, 'Output image size: ', nx, ny
;
siz = size(data)
typ = siz( siz(0)+1 )
data_out = make_array(nx, ny, n, type=typ)
;
for i=0,n-1 do begin
    data0 = make_array(nx, ny, type=typ)
    data0( x_embed(i), y_embed(i) ) = data(*,*,i)	;embed input data into a larger array
    ;
    x0 = corn2sc(0,i) - x_embed(i)
    y0 = corn2sc(1,i) - y_embed(i)
    ;data_out(0,0,i) = rot(data0, angle(i), mag, -x0, -y0, missing=missing, /pivot)
    data_out(0,0,i) = rot(data0, angle(i), mag, missing=missing)
    ;
    if (keyword_set(index)) then begin
	his_index, index_out, i, 'corner_sav', new_corn(*,i) + cen(0:1,i)
	index_out(i).sxt.shape_sav = [nx, ny]
    end
end
;
if (keyword_set(qstop)) then stop
return, data_out
end
