;+
;       NAME: DSK_LOCG
;
;       PURPOSE: A much better disk locator for spectral images
;
;       METHOD:  Find a sequence of limb points and then use a chi
;		 squared fitting technique to fit as circle or ellipse.
;
;
;       CALLING SEQUENCE:	trgt = dsk_locg(specimg,np,/cir,/inter,/major)
;
;
;       PARAMETERS:		specimg	input GBO image 
;				np	number of limbpoints to use
;				trgt	return fit parameters
;					centroid: [x,y] 
;					minor axis
;					eccentricity  (for ellipse only)
;					major axis angle: x-axis is 0. (for ellipse only)
;
;       KEYWORDS:		inter	when set do interactive culling of 
;					limb points turned on.
;				major	set when major rather than minor
;					axis is available
;				cir	when set use circular fit
;				quiet	when set DO NOT display work
;
;	CALLS:	DSKCNTR,LIMBPNTS,EDIT_PNTS,CIRCLE_TRGT,CIRCLE_FIT,
;		ELLIPSE_FIT,CIRCLE_FN,ELLIPSE_FN
;
;       HISTORY: Drafted by AMcA, August 1994.
;		 Replaced circle fitter with Metcalf's CIRCLE_FIT, AMcA, Nov. 1994.
;		 Fixed typo in CIRCLE_FIT call, AMcA, Mar. 1995.
;
;                16-may-95 (SLF) - inhibit plot (via quiet) for background tasks
;-
FUNCTION dsk_locg,specimg,np,inter=inter,cir=cir,major=major,quiet=quiet

; slf - 16-may-95 dont do display if this is running in the background (idl_batch)
quiet=keyword_set(quiet) or (get_logenv('ys_batch'))(0) ne ''

rufcnt=dskcntr(specimg)					;estimate disk center

rlimb=limbpnts(specimg,rufcnt,np,quiet=quiet)		;find limbpoints

;query for major rather than minor axis fit?

mode = 0					;set mode for chi square

if keyword_set(inter) then begin

	limb=edit_pnts(rlimb)			;cull the points interactively
	
endif else limb = rlimb

if keyword_set(cir) then begin

	ctrgt=circle_trgt(limb)
	circle_fit,limb(0,*),limb(1,*),ctrgt(0),ctrgt(1),ctrgt(2),x0,y0,r0		;feed limb to circle fitter
	trgt=[x0,y0,r0]

endif else trgt=ellipse_fit(limb,fit,mode,major=major,quiet=quiet)	;feed limb to ellipse fitter


if not quiet then begin

  if keyword_set(cir) then begin  
  
  	curve=circle_fn(trgt,rlimb(0,*),rlimb(1,*))	
  	
  endif else curve=ellipse_fn(trgt,rlimb(0,*),rlimb(1,*))
  
  plots,curve(0,*),curve(1,*),psym=0,/device,color=255	;plot it
  
endif

return, trgt			

end
