pro mk_gsn_obs, tape_name, dev=dev, outdir=outdir, outfil=outfil, $
		run_time=run_time, qstop=qstop, qdb=qdb, q2db=q2db, $
		save_header=save_header, save_img=save_img, archive_fulldisk=archive_fulldisk
;
;+
;NAME:
;	mk_gsn_obs
;PURPOSE:
;	Generate the observing log file from a SOON/SPOT archive tape
;SAMPLE CALLING SEQUENCE:
;	mk_gsn_obs
;OPTIONAL INPUT:
;	tape_name - The name of the tape
;		  The tape name can be derived from the tape contents, 
;		  but this is not completely accurate.
;OPTIONAL KEYWORD INPUT:
;	dev	- The device number.  If not defined, it uses dev=0
;	outfil	- The output filename to create, excluding the directory
;		  portion.  If not passed, the tape_name is used.
;	save_header - If set, then the FITS header for "save_header" images 
;		  for each file will be saved to an output file.
;	save_img - If set, then a FITS image for "save_img" images 
;		  for each file will be saved to an output file.
;OPTIONAL KEYWORD INPUT:
;	outdir	- The output directory
;RESTRICTION:
;HISTORY:
;	Written 7-Dec-93 by M.Morrison
;V0.02	13-Dec-93 (MDM) - Changed the MK_GSN_OBS_S1 routine 
;			- Added SITE and IMAGE_TYPE updating
;			- Corrected angular calculation for PFI location
;V0.03	 4-Jan-94 (MDM) - Added the list of observing sites
;V0.04	26-Jul-94 (MDM) - Changed logic to write out temporary file and
;			  to figure out the file name from the first image
;			  on the tape.
;			- Replaced SPAWN with call to MTCMD
;V0.05	27-Jul-94 (MDM) - Added SAVE_IMG option
;V0.06	27-Jul-94 (MDM) - Revised to save "per tape file" structure at the
;			  end of the file like a "roadmap" instead of at the
;			  beginning so that we don't have to waste space
;			  (we were having to allocate the maximum amount of
;			  space to insure it would fit).
;			- Started saving .IMAGE_AVG
;V0.10	28-Jul-94 (MDM) - Starting archiving a single full disk image per
;			  tape file
;V0.20	28-Jul-94 (MDM) - Corrected to save only full disk images
;V0.30	 2-Aug-94 (MDM) - Corrected location derivation.  Previously it was
;			  not correcting for the P-angle.
;V0.40	 3-Aug-94 (MDM) - Change "IMAGE_TYPE" to "C" for large scale h-alpha
;			  images.
;V0.50	 3-Aug-94 (MDM) - Save bad headers when location and pixel size is not
;			  good, as well as bad time/date field
;			- Added retry on OPEN of drive unit
;V0.51	 4-Aug-94 (MDM) - Changed the format of the BAD header output file
;			  (list the bad pixel size)
;V0.52	 4-Aug-94 (MDM) - Fixed incorrect location printing statements
;V1.00	 8-Aug-94 (MDM) - Modified to save the AVERAGE center of image location
;			  instead of the location for the last image.
;			- Cap the deviation from the first position at
;			  32000
;V1.01	22-Sep-94 (MDM) - Patched GSN_INFO so that it used the site info
;			  in the tape name if it is unknown in the FITS header
;V1.02	03-Nov-95 (GLS) - Replaced reference to /ydb/ref_scratch to
;			  get_logenv('DIR_REFORMAT_SC').
;-
;
progVerNo = 1.010*1000
progName = 'MK_GSN_OBS'
;
start_time = systime(1)
run_time = 0.
if (n_elements(outdir) eq 0) then outdir = getenv('DIR_GSN_OBS')
if (n_elements(dev) eq 0) then dev = 0
t = get_logenv('DIR_REFORMAT_SC')
outdir_temp = t
;
dev = def_tapd(dev)
;
;----- Call subroutines that define the structures
;
obs_struct
soon_struct, gsn_version=gsn_version
gen_struct, file_header=fhead
;
;----- Diagnostic variables
;
qprint = 1
if n_elements(qdb) eq 0 then qdb = 1
if n_elements(q2db) eq 0 then q2db = 0
;
;---------------------------------------- General Stuff
;
spacecraft = 'GBO'
;
lunout = 2	;output 
lun = 3		;for reading the data file
;
norbitmax       = 300
orbit_header    = {obs2_neworb_hd_rec}
orbit0          = {gsn_pointer_rec}
orbit_arr       = replicate(orbit0, norbitmax)
;
qfirst_time = 1
first_time      = 0
first_day       = 0
last_time       = 0
last_day        = 0
;
rsiz = 16
;
ndatasets = 0L
norbit    = 0
;
itapefile = 1
itotimg = 0
;
if (keyword_set(qstop)) then stop
;
;-------------------- Start tape access
;
;get_lun, lun   ;can't use get_lun because MTCMD does a free_lun and conflicts insue.
lun = 13
mtcmd, dev, /rewind             ;spawn, 'mt -f ' + dev + ' rewind'
on_ioerror, skip_io1
ntry = 0
skip_io1:
ntry = ntry + 1
if (ntry gt 1) then print, 'Trouble opening tape drive.  Try #', ntry
if (ntry gt 5) then stop
openr, lun, dev
;
buff = bytarr(240)		;first file is label information plus a VMS/FILES11 start file marker
on_ioerror, skip_io2
readu, lun, buff
skip_io2:
;
label = string(buff(0:7))
print, 'TAPE LABEL IS: ', label
;
;outfil = strlowcase(label) + '.catalog'
if (n_elements(outfil) eq 0) then begin
    if (n_elements(tape_name) eq 0) then begin
	outfil = concat_dir(outdir_temp, 'st_temp_' + ex2fid(anytim2ex(!stime)))
	outfil_final = concat_dir(outdir, 'st_temp_' + ex2fid(anytim2ex(!stime)))
    end else begin
	outfil = concat_dir(outdir_temp, tape_name+'.cat')
	outfil_final = concat_dir(outdir, tape_name+'.cat')
    end
end
;
if (file_exist(outfil)) then file_delete, outfil
print, 'Opening a new output file: ', outfil
open_da_file, lunout, '', '', outfil, rsiz, bytout, fpoint, /nolower
fpoint.data_section	= bytout
;
neof = 0
eot = 0
if (not keyword_set(tape_name)) then tape_name = ''
while (not eot) do begin
    mk_gsn_obs_s1, lun, tape_name, eot, itapefile, neof, obs, obshdr, qdb=qdb, q2db=q2db, $
		save_header=save_header, save_img=save_img, archive_fulldisk=archive_fulldisk
    if ((not eot) and (obshdr.n_images ne 0)) then begin
	orbit_arr(norbit).stEntry = ndatasets + 1	;dataset # for which this orbit starts (start counting at 1)
	orbit_arr(norbit) = obshdr
	norbit = norbit + 1

	rdwrt, 'W', lunout, bytout, rsiz, obs, 1
	ndatasets = ndatasets + n_elements(obs)
    end
end
;
fpoint.opt_section	= bytout
orbit_header.nOrbitRec  = norbit
rdwrt, 'W', lunout, bytout, rsiz, Orbit_header, 1
rdwrt, 'W', lunout, bytout, rsiz, orbit_arr(0:norbit-1), 1
totbytes = bytout
;
obshdr0 = orbit_arr(0:norbit-1)
x = int2secarr(obshdr0)
dummy = min(x, ii)
first_day  = obshdr0(ii).day
first_time = obshdr0(ii).time
x = int2secarr(anytim2ints(obshdr0, off=obshdr0.duration))
dummy = max(x, ii)
last_day  = obshdr0(ii).day
last_time = obshdr0(ii).time
;
maxsamps = max(obshdr.image_shape(0)) * long(max(obshdr.image_shape(1)))

;-------------------- Write out pointer and file header
;

fpoint.TotBytes		= totbytes

fhead.first_Time	= first_time
fhead.first_Day		= first_day
fhead.last_Time		= last_time
fhead.last_Day		= last_day

fhead.nDataSets		= nDataSets
fhead.maxSamps		= maxSamps
fhead.ntot_opt		= n_elements(obshdr)

fpoint.data_version     = gsn_version.data
fpoint.roadmap_version	= gsn_version.roadmap

file_id = ' '	;TODO - make it something else?
wrt1p_fh, lunout, fpoint, fhead, rsiz, progName, progVerNo, file_id, 'GSN', 'All', $
			progname2=progname2, progverno2=progverno2, spacecraft=spacecraft
;
close, lunout
;
if (n_elements(outfil_final) ne 0) then if (outfil_final ne outfil) then begin
    cmd = 'rm -f ' + outfil_final               ;remove any copy of the file that might already exist
    spawn, cmd
    cmd = 'mv ' + outfil + ' ' + outfil_final
    spawn, cmd
    cmd = 'chmod +w ' + outfil_final
    spawn, cmd
    outfil = outfil_final
end
;
end_time = systime(1)
run_time = (end_time-start_time)/60.
print, 'MK_GSN_OBS took', run_time, ' minutes to run'
;
free_lun, lun
if (keyword_set(qstop)) then stop
mtcmd, dev, /offline
end
