function rd_selsisi, infil, head=head, fits_head=fits_head, bhead=bhead, outfil=outfil, qerror=qerror, qstop=qstop
;
;+
;NAME:
;	rd_selsisi
;PURPOSE:
;	To read the SELSIS image data files
;CALLING SEQUENCE:
;	img = rd_selsisi(infil, head=head)
;	img = rd_selsisi(infil, head=head, fits_head=fits_head)
;INPUT:
;	infil	- The input file name.  This needs to be the standard
;		  SELSIS format in order to extract the date/time
;OUTPUT:
;	Returns a 512x512 byte array with the image.  The image is
;	rotated and translated so that it appears properly using IDL
;KEYWORD OUTPUT:
;	head	- a structure with the header information
;	fits_head- A string array with the fits header
;	bhead	- the raw header array (a 512 byte array)
;	outfil	- The YOHKOH output file name
;	qerror	- Set if there was an error reading the file.
;HISTORY:
;	Written 1-Jul-92 by M.Morrison
;	16-Jul-92 (MDM) - Expanded header information and FITS header
;			  Added "outfil" parameter
;	13-Oct-92 (MDM) - Added QERROR
;	 9-Aug-93 (MDM) - Added check that the time/header was not
;			  corrupted
;	 4-Oct-93 (MDM) - Added another check that the time/header was not
;			  corrupted
;			- Added /QSTOP
;-
;
qerror = 0
ff = findfile(infil)
if (ff(0) eq '') then message, 'Input file ' + infil + ' cannot be found'		;stops
;
openr, lun, infil, /get_lun
bhead = bytarr(512)
img = bytarr(512,512)
on_ioerror, ioerror
;
readu, lun, bhead
readu, lun, img
img = rotate(img, 7)
free_lun, lun
;
break_file, infil, dsk_log, dir, filnam, ext
;date = strmid(filnam,5,2) + '/' + strmid(filnam,3,2) + '/' + strmid(filnam,1,2)	;dd/mm/yy
;time = strmid(filnam,7,2) + ':' + strmid(filnam,9,2) + ':' + strmid(filnam,11,2)	;hh:mm:ss
date = string(bhead([13,12,11]), format="(i2.2, '/', i2.2, '/', i2.2)")
time = string(bhead([15,16,17]), format="(i2.2, ':', i2.2, ':', i2.2)")
fileid = string(bhead([11,12,13]), bhead([15,16]), format="(3i2.2, '.', 2i2.2)")
;
if (keyword_set(qstop)) then stop
delta = int2secarr( fid2ex(fileid), !stime)	;added 4-Oct-93 (see if date/time makes sense)
if ((bhead(11) lt 90) or (bhead(11) gt 96) or (bhead(12) gt 12) or (delta gt 24*60.*60.)) then begin	;MDM added 9-Aug-93
    ;corrupted time
    qerror = 1
    print, 'RD_SELSISI: Corrupted selsis file header - bad date/time
    return, img
end
;
station_code = bhead(10)
case station_code of
    1: begin & station = 'Boulder'		& pre = 'gc'	& end
    2: begin & station = 'Holloman'		& pre = 'gh'	& end
    3: begin & station = 'Kitt Peak'		& pre = 'gk'	& end
    4: begin & station = 'Leamonth, Australia'	& pre = 'gl'	& end
    5: begin & station = 'GSFC'			& pre = 'gg'	& end
    else: begin & station = '???'		& pre = 'g_'	& end
endcase
;
fits_head = strarr(20)
fits_head(0) = 'SIMPLE  =' + string('T',		format="(a20, ' /')")
fits_head(1) = 'BITPIX  =' + string(8,			format="(i20, ' /')")
fits_head(2) = 'NAXIS   =' + string(2,			format="(i20, ' /')")
fits_head(3) = 'NAXIS1  =' + string(512,		format="(i20, ' /')")
fits_head(4) = 'NAXIS2  =' + string(512,		format="(i20, ' /')")
fits_head(5) = '  '
fits_head(6) = 'TIME-OBS=' + string(time,		format="(a20, ' /')")
fits_head(7) = 'DATE-OBS=' + string(date,		format="(a20, ' /')")
fits_head(8) = 'STA-CODE=' + string(station_code,	format="(a20, ' /')")
fits_head(9) = 'STATION =' + string(station,		format="(a20, ' /')")
fits_head(10)= 'PROJECT =' + string('SELSIS-SOON',	format="(a20, ' /')")
fits_head(11)= '  '
fits_head(12)= 'SEEING  =' + string(bhead(89),		format="(i20, ' / 1=v. poor, 2=poor, 3=fair, 4=good, 5=excellent')")
fits_head(13)= 'QUALITY =' + string(bhead(90),		format="(i20, ' / 1=Severly compromised, 2=compromized, 3=average')")
fits_head(14)= '         ' + string(' ',		format="(a20, ' / 4=better than average, 5=excellent')")
fits_head(15)= 'PRJECTN =' + string(bhead(91),		format="(i20, ' / 1=full disk, 2=large scale, 3=area scan')")
fits_head(16)= 'D.TYPE  =' + string(bhead(92),		format="(i20, ' / 1=H-alpha, 2=white/B2, 3=Magnetic, 4=He 10830A')")
fits_head(17)= '         ' + string(' ',		format="(a20, ' / 5=spectohelioscope, 6=x-ray')")
								      ;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
fits_head(18)= ' '
fits_head(19)= 'COMMENT  ' + string(bhead(19:88))
;
case bhead(92) of
    1: prefix = pre + 'h'	;h-alpha
    2: prefix = pre + 'w'	;white light
    3: prefix = pre + 'm'	;magnetic
    4: prefix = pre + 'i'	;He 10830A
    5: prefix = pre + 's'	;spectrohelioscope
    6: prefix = pre + 'x'	;x-ray
    else: prefix = pre + '_'
endcase
;
outfil = prefix + fileid
;
return, img
;
ioerror:
    free_lun, lun
    qerror = 1
    return, img    
end
