;+
; NAME: sol_rot
;
;
; PURPOSE: To take pixels in a 2D image map them onto a sphere, rotate the  
;  	   sphere map the pixels back to the plane. For use in extrapolating 
;	   GBO data backward or forward in time.                              
;
; METHOD: Take the pixel coordinates of the on disk points, map them 
;	  to heliocentric coordinates, add the appropriate differential 
;	  rotation, and map them back. 
;	  All pixels that have rotated behind the limb are marked by [-1,-1]
;	  entries. For now just take longitude to +/- 90.
;
; CALLING SEQUENCE:
;			out=gbo_rot_t(xx,yy,trgt,date,delt[,roll=roll])
;
; PARAMETERS: 	
;		pixx 	vector with the x pixel coordinates.
;		pixy	vector with the y pixel coordinates.
;		trgt	a three vector, with the centroid and radius in the 
;			same size pixels as the image.
;		date 	the time of the image, in standard 7 part form, 
;			[DD-MMM-YY HH:MM:SS].
;		delt	the rotation time, in decimal days.
;		out     the return is a 2xn matrix with the new x & y pixel 
;			coordinates. 
;
; KEYWORDS:	roll 	optional roll correction. For SXT images you can
;			use 1.0.
;		stretch optional return. factor measuring the longitudinal 
;			contraction/expansion of each pixel.
;
;
; RETURN TYPE:
; 
; CALLS: CONV_P2H, CONV_H2P, DIFF_ROT                                         
;
; HISTORY: Drafted by A.McAllister, Feb. 1993.
;	   Reworked for new conversion routines, Jun. 1993.
;	   16-Oct-93 (MDM) - Modified call to CONV_P2H and H2P to use the
;			     keyword input "roll" instead of "tilt"
;	   Corrected output assignment indexing???, AHM, Dec 1, 93.
;
;-
FUNCTION sol_rot,pixx,pixy,trgt,date,delt,roll=roll,stretch=stretch
 
 pix_num=n_elements(pixx)

 if keyword_set(roll) eq 0 then roll = 0

;convert to heliographic, rotate, convert back

 pixlnlt=conv_p2h([pixx,pixy],date,suncenter=trgt(0:1), $
		   radius=trgt(2),roll=roll,off_limb=off_limb)
	
 pixdln=diff_rot(delt,pixlnlt(1,*),/howard)  	

 pixlnlt(0,*)=pixlnlt(0,*)+pixdln
 pixdln=0				;reduce memory

 temp=conv_h2p(pixlnlt,date,suncenter=trgt(0:1),radius=trgt(2),roll=roll, $
		                                            behind=behind)

 od_ss=where(behind ne 1 ) 

 if n_elements(od_ss) eq 0 then print,'SOL_ROT: all pixels are behind the limb'

 if n_elements(od_ss) ge 1 and n_elements(od_ss) lt pix_num then $
				     print,'SOL_ROT: there are pixels behind the limb'

 newpix=fltarr(2,pix_num)
 newpix(*,*)=-1.0

 newpix(0,od_ss)=temp(0,od_ss)
 newpix(1,od_ss)=temp(1,od_ss)
 
return,newpix 

end


