pro soon2fits, tape_files0, image_list0, dev=dev, $
		run_time=run_time, qstop=qstop, qdebug=qdebug, outdir=outdir, offline=offline, eject=eject
;
;+
;NAME:
;	soon2fits
;PURPOSE:
;	Take a SOON tape and extract certain images into FITS files.
;SAMPLE CALLING SEQUENCE:
;	soon2fits, 1
;	soon2fits, 1, [4,5,6]
;	soon2fits, tape_files, image_list, dev=dev
;OPTIONAL INPUT:
;	tape_files - The tape file numbers to extract.  If omitted, it
;		     will read all files.  Start counting at 1.
;	image_list - The images to extract for that tape file.  If omitted,
;		     it will extract all images.  First image is 1.
;OPTIONAL KEYWORD INPUT:
;	dev	- The device number.  If not defined, it uses dev=0
;	offline	- Eject the tape after reading
;	eject	- Eject the tape after reading
;	outdir	- The output directory.  The default is the directory
;		  which you are running from.
;METHOD:
;	For every TAPE file, there is a 240 (or 120) byte file in front
;	and in back of the tape file.  So it is:
;		Junk File1 Junk Junk File2 Junk Junk File3
;	Those "junk" files are the VMS FILES11 beginning of file and
;	end of file headers.
;HISTORY:
;	Written 28-Jul-93 by M.Morrison
;	 3-Aug-94 (MDM) - Added /EJECT
;			- Corrected some logic (allowed backward positioning 
;			  to work properly)
;			- Sorted the "tapefiles" list to do them in order
;-
;
progVerNo = 1.000*1000
progName = 'SOON2FITS
qdebug = 1
;
start_time = systime(1)
run_time = 0.
if (n_elements(outdir) eq 0) then outdir = ''
if (n_elements(dev) eq 0) then dev = 0
if (n_elements(tape_files0) eq 0) then tape_files = indgen(300)+1 else tape_files = tape_files0
if (n_elements(image_list0) eq 0) then image_list = indgen(300)+1 else image_list = image_list0
;
if (n_elements(tape_files) gt 1) then tape_files = tape_files(sort(tape_files))		;do tape files in order
;
dev = def_tapd(dev)
;
;-------------------- Start tape access
;
;get_lun, lun	;can't use get_lun because MTCMD does a free_lun and conflicts insue.
lun = 13
mtcmd, dev, /rewind		;spawn, 'mt -f ' + dev + ' rewind'
on_ioerror, skip_io1
ntry = 0
skip_io1:
ntry = ntry + 1
if (ntry gt 1) then print, 'Trouble opening tape drive.  Try #', ntry
if (ntry gt 5) then stop
openr, lun, dev
;
buff = bytarr(2880)		;first file is label information plus a VMS/FILES11 start file marker (240 bytes)
on_ioerror, skip_io2
readu, lun, buff
skip_io2:
;
label = string(buff(0:7))
if (keyword_set(qdebug)) then print, 'Tape label: ' + label
;
eot = 0
qdone = 0
curfile = 1
itape = 0
while (not qdone) do begin
    while (itape le n_elements(tape_files)-1) do begin
	nextfile = tape_files(itape)
	print, 'Extracting images from file: ' + strtrim(nextfile,2) + ' on drive: ' + dev
	delfile = nextfile - curfile
	case 1 of
	    (delfile eq 0):  ;do nothing
	    (delfile gt 0):  mtcmd, dev, fsf=delfile*3		;*3 because of 1 for file, 2 for marks between files
	    (delfile lt 0):  begin
				mtcmd, dev, bsf=abs(delfile)*3+1	;+1 because of funny tape positioning
				mtcmd, dev, fsf=1			;move to the other side of the EOF mark (?!?!?)
			     end
	    else: 						;do nothing
	endcase
	stat = fstat(lun)
	if (stat.open eq 0) then openr, lun, dev		;mtcmd closes the unit!!!!!
	qeof = 0
	iimg = 0
	neof = 0
	while (not qeof) do begin
	    on_ioerror, io_prob
	    h = bytarr(2880*2)
	    if (iimg eq 0) then readu, lun, h $
			else readu, lun, h, img, pad
	    h_str = string(reform(h,80,72))
	    iimg = iimg + 1
	    neof = 0            ;reset the number of consecutive EOF counter
	    if (iimg eq 1) then begin
		ss = where(strmid(h_str, 0, 8) eq 'NAXIS1  ')   & nx   = long(strmid(h_str(ss(0)), 10, 20))
		ss = where(strmid(h_str, 0, 8) eq 'NAXIS2  ')   & ny   = long(strmid(h_str(ss(0)), 10, 20))
		img = bytarr(nx, ny)
		pad = bytarr(2880 - (nx*ny mod 2880))
		readu, lun, img, pad
	    end

	    ss = where(image_list eq iimg)
	    if (ss(0) ne -1) then begin			;this image is on the list
		gsn_info, h_str, tim, site, image_type

		outfil = 'g' + strlowcase( site ) + strlowcase( image_type ) + ex2fid( anytim2ex(tim) , /sec)
		outfil = concat_dir(outdir, outfil)
		if (keyword_set(qdebug)) then print, 'Saving: ' + outfil
		wrt_fits, outfil, h_str, img
	    end

	    goto, skip
	    io_prob:
		qeof = 1
		if (keyword_set(qdebug)) then print, !err_string
		neof = neof + 1
		if (neof gt 5) then eot=1       ;got to the end of the tape - expect 2-3 eof between files
	    skip:
	end
	itape = itape + 1
	mtcmd, dev, fsf=2			;skip forward 2 marks
	curfile = nextfile+1
    end

    if (itape ge n_elements(tape_files)) then qdone = 1
    if (eot) then qdone = 1
end    
;
end_time = systime(1)
run_time = (end_time-start_time)/60.
print, 'SOON2FITS took', run_time, ' minutes to run'
;
free_lun, lun
if (keyword_set(qstop)) then stop
if (keyword_set(offline) or keyword_set(eject)) then mtcmd, dev, /offline
if (n_elements(outfil) eq 0) then begin
    print, 'Exiting without having written any files.  Stopping...'
    stop
end
;
end

