pro sxt2fits, index, data, outfil=outfil, infil=infil, ss=ss, outdir=outdir, $
	qstop=qstop, quiet=quiet
;
;+
;NAME:
;	sda2fits
;PURPOSE:
;	Take a SXT index and data and write a FITS file
;CALLING SEQUENCE:
;	sxt2fits, index, data
;	sxt2fits, index, data, outfil='sda_sample.fits'
;	sxt2fits, infil=infil
;	sxt2fits, infil=infil, ss=ss
;	sxt2fits, infil='$DIR_SXT_SFM/sfm930300.0000', outdir='/yd3/morrison/sgd'
;INPUT:
;	index	- The index structure to be saved
;	data	- The data array to be saved
;OPTIONAL KEYWORD INPUT:
;	outfil	- The output file name(s).  There should be one filename
;		  per image saved.  If "outfil" is not specified, then
;		  the output file name is:
;			SF_FITSyymmdd.hhmmss	(for FFI)
;			SP_FITSyymmdd.hhmmss	(for FFI)
;		  If "outfil" is passed as a scalar and there are
;		  multiple images passed in, then a .0001, .0002, .0003
;		  and so forth is appended to the end.
;	infil	- Instead of passing in the "index" and "data", it
;		  is possible to pass in the SDA file name.  If 
;		  "ss" is not passed, then all data sets are saved
;	ss	- A list of the indicies to be saved (either within
;		  the "index" variable, or datasets within the
;		  "infil"
;	outdir	- The output directory where to put the FITS file created
;OUTPUT:
;	Creates FITS files
;HISTORY:
;	Written 19-Oct-92 by M.Morrison
;	 5-May-93 (MDM) - Modification to the header
;	 6-Mar-95 (MDM) - Added center pixel information (as per Hudson's Request)
;	 8-Mar-95 (GAL) - Fixed typo-bug from 6-Mar-95
;       10-may-95 (SLF) - add CRROTA and call to get_roll
;	23-Jun-95 (MDM) - Removed the blank lines in the header (put COMMENT)
;	26-Jun-95 (MDM) - Replaced all of the format statements to build the
;			  FITS header with calls to SXADPAR
;        7-aug-95 (SLF) - change DATE-OBS to conform to NOST FITS stds.
;			  add DATEOBS (Yohkoh String Format Time & Date)
;       22-sep-95 (SLF) - add QUIET keyword and function
;-
;
loud=1-keyword_set(quiet)

if (n_elements(outdir) eq 0) then outdir = ''
if (keyword_set(infil)) then begin
    qinfil = 1
    rd_roadmap, infil, roadmap
    if (n_elements(ss) eq 0) then ss = indgen(n_elements(roadmap))
    input1 = roadmap(ss)
end else begin
    qinfil = 0
    if (n_elements(index) eq 0) then begin
	print, 'SXT2FITS: No input file specified and no index passed
	print, 'Returning...
	return
    end
    if (n_elements(ss) eq 0) then ss = indgen(n_elements(index))
    input1 = index(ss)
end
noutfil = n_elements(ss)
;
if (keyword_set(outfil)) then begin
    outfil0 = outfil
    if (n_elements(outfil) ne noutfil) then outfil0 = outfil(0) + '.' + string(indgen(noutfil), format='(i4.4)')
end else begin
    prefix_arr = ['sp_fits', 'sf_fits']
    ii = gt_pfi_ffi(input1) mod 2	;b0 = 0 is PFI
    prefix = prefix_arr(ii)
    tims = anytim2ints(input1)
    out_fids = ex2fid( anytim2ex(tims), /sec )
    outfil0 = prefix + out_fids
end
;
if (keyword_set(qstop)) then stop
;
for ifil=0,noutfil-1 do begin
    if (qinfil) then begin
	rd_xda, infil, ss(ifil), index0, data0, roadmap
    end else begin
	index0 = index(ss(ifil))
	data0 = data(*,*,ss(ifil))		;TODO - what about images that have been padded during the read?
    end
    ;
    nbits = get_nbytes(data0(0,0))*8
    time = gt_time(index0, /str)
    date_time = strcompress(fmt_tim(index0))
    fits_date=gt_day(index0,/str,/fits)		; slf, 7-aug-95
    siz = size(data0)
    naxis1 = siz(1)
    naxis2 = siz(2)

    cen = sxt_cen(index0)
    crpix = ( cen - gt_corner(index0) ) / (2^gt_res(index0))	;in units of output pixels
	; Above line updated from copy below by GAL 8-Mar-95
    crpix = crpix + 1						;add 1 since FITS starts at 1, not 0.
    crota = get_roll(index0,status=status)
    roll_mess=([' PROCESSED (Error +/- .05 Deg)', $
                ' PREDICTED (Error +/- .3 Deg)'])(status(0))
    roll_mess=' Degrees CCW: ' + roll_mess
    rad = get_rb0p(index0(0),/rad)/gt_pix_size(gt_res(index0(0)))
	; Above line updated from copy below by GAL 8-Mar-95
;    rad = get_rb0p(index(0),/rad)/gt_pix_size(gt_res(index(0)))
    ;
    sxaddpar, fits_head, 'SIMPLE', 	'T'
    sxaddpar, fits_head, 'BITPIX', 	nbits
    sxaddpar, fits_head, 'NAXIS',	2
    sxaddpar, fits_head, 'NAXIS1',	naxis1
    sxaddpar, fits_head, 'NAXIS2',	naxis2
    sxaddpar, fits_head, 'DATE-OBS', 	fits_date,                      ' DD/MM/YY  [UT]'
    sxaddpar, fits_head, 'TIME-OBS', 	time,			        ' hh:mm:ss [UT]'
    sxaddpar, fits_head, 'CRPIX1',	crpix(0),			' sun E/W center (pixels 1-NAXIS1)'
    sxaddpar, fits_head, 'CRPIX2',	crpix(1),			' sun N/S center (pixels 1-NAXIS2)'
    sxaddpar, fits_head, 'CROTA',	crota,				roll_mess
    sxaddpar, fits_head, 'RADIUS',	rad,				' Radius of sun (pixels)
    sxaddpar, fits_head, 'FILTER-A',	gt_filta(index0,/str), 		' 1=Open , 2=NaBan, 3=Quart'
    sxaddpar, fits_head, 'HISTORY',		'                         4=Diffu, 5=WdBan, 6=NuDen', after='FILTER-A'
    sxaddpar, fits_head, 'FILTER-B', 	gt_filtb(index0,/str),		' 1=Open , 2=Al.1 , 3=AlMg '
    sxaddpar, fits_head, 'HISTORY',		'                         4=Be119, 5=Al12 , 6=Mg3  ', after='FILTER-B'
    sxaddpar, fits_head, 'RESOLUT',	gt_res(index0,/str),		' Full=2.46 arcsec pixel, half=4.92, qrtr=9.84'
    sxaddpar, fits_head, 'EXP-TYPE',	gt_expmode(index0,/str),	' Normal, dark, calibration'
    sxaddpar, fits_head, 'EXP-DUR',	gt_expdur(index0),		' Exposure duration in milliseconds'
    sxaddpar, fits_head, 'EXP-LEV',	gt_dpe(index0),			' DPE (commanded exposure level 0 to 32)'
    sxaddpar, fits_head, 'DP-MODE',	gt_dp_mode(index0,/str),	' S/C Data Processor (DP) Science Mode'
    sxaddpar, fits_head, 'DP-RATE',	gt_dp_rate(index0,/str),	' S/C Data Processor (DP) Telemetry Rate'
    sxaddpar, fits_head, 'DATEOBS', 	date_time,			' Start CCD Integration [UT]'

    if loud then print, 'SDA2FITS: Now saving ', outfil0(ifil)
    wrt_fits, concat_dir(outdir, outfil0(ifil)), fits_head, data0
end
;
end
